@@ -77,7 +77,7 @@ checkfail()
 if [ ! -d "gradle/wrapper" ]; then
     echo "Downloading gradle"
     GRADLE_VERSION=2.10
-    GRADLE_URL=http://services.gradle.org/distributions/gradle-${GRADLE_VERSION}-all.zip
+    GRADLE_URL=http://download.videolan.org/pub/contrib/gradle-${GRADLE_VERSION}-all.zip
     wget ${GRADLE_URL} 2>/dev/null || curl -O ${GRADLE_URL}
     checkfail "gradle: download failed"
 
@@ -99,6 +99,28 @@ if [ ! -d "gradle/wrapper" ]; then
     rm -rf gradle-${GRADLE_VERSION}-all.zip gradle-${GRADLE_VERSION}
 fi
 
+###############
+# SDK Manager #
+###############
+
+if [ ! -f "gradle/plugins/sdk-manager-plugin.jar" ]; then
+    cd gradle/
+    if [ -d "sdk-manager-plugin" ]; then
+        rm -rf sdk-manager-plugin
+    fi
+    git clone https://github.com/JakeWharton/sdk-manager-plugin.git
+    cd sdk-manager-plugin
+    git reset --hard 1d29782dd6ffa18880c8cbada748fb3dea45e7be
+    ./gradlew assemble
+    cd ..
+    if [ ! -d "plugins" ]; then
+        mkdir plugins
+    fi
+    mv sdk-manager-plugin/build/libs/sdk-manager-plugin-1.5.0-SNAPSHOT.jar plugins/sdk-manager-plugin.jar
+    rm -rf sdk-manager-plugin
+    cd ..
+fi
+
 ####################
 # Configure gradle #
 ####################
@@ -202,7 +224,12 @@ if [ "$BUILD_LIBVLC" = 1 ];then
     RUN=0
     CHROME_OS=0
 else
-    TARGET="assemble${PLATFORM}${GRADLE_ABI}${BUILDTYPE}"
+    if [ "$RUN" = 1 ]; then
+        ACTION="install"
+    else
+        ACTION="assemble"
+    fi
+    TARGET="${ACTION}${PLATFORM}${GRADLE_ABI}${BUILDTYPE}"
     PASSWORD_KEYSTORE="$PASSWORD_KEYSTORE" ./gradlew $TARGET
 fi
 
@@ -213,11 +240,9 @@ if [ "$RUN" = 1 ]; then
     export PATH=${ANDROID_SDK}/platform-tools/:$PATH
     adb wait-for-device
     if [ "$RELEASE" = 1 ]; then
-        adb install -r vlc-android/build/outputs/apk/vlc-android-vanilla-release.apk
-        adb shell am start -n org.videolan.vlc/org.videolan.vlc.gui.MainActivity
+        adb shell am start -n org.videolan.vlc/org.videolan.vlc.StartActivity
     else
-        adb install -r vlc-android/build/outputs/apk/vlc-android-vanilla-debug.apk
-        adb shell am start -n org.videolan.vlc.debug/org.videolan.vlc.gui.MainActivity
+        adb shell am start -n org.videolan.vlc.debug/org.videolan.vlc.StartActivity
     fi
 fi
 
