@@ -69,6 +69,7 @@ import org.videolan.vlc.gui.AudioPlayerContainerActivity;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.preferences.PreferencesActivity;
 import org.videolan.vlc.gui.preferences.PreferencesFragment;
+import org.videolan.vlc.gui.video.PopupManager;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.media.MediaDatabase;
 import org.videolan.vlc.media.MediaUtils;
@@ -186,6 +187,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
      */
     private long mWidgetPositionTimestamp = Calendar.getInstance().getTimeInMillis();
     private ComponentName mRemoteControlClientReceiverComponent;
+    private PopupManager mPopupManager;
 
     private static LibVLC LibVLC() {
         return VLCInstance.get();
@@ -362,8 +364,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                         Log.i(TAG, "AUDIOFOCUS_LOSS");
                         // Pause playback
                         changeAudioFocus(false);
-                        if (wasPlaying)
-                            pause();
+                        pause();
                         break;
                     case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT:
                         Log.i(TAG, "AUDIOFOCUS_LOSS_TRANSIENT");
@@ -496,6 +497,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             } else if (action.equalsIgnoreCase(ACTION_REMOTE_LAST_VIDEO_PLAYLIST)) {
                 loadLastPlaylist(TYPE_VIDEO);
             } else if (action.equalsIgnoreCase(ACTION_REMOTE_SWITCH_VIDEO)) {
+                removePopup();
                 if (hasMedia()) {
                     getCurrentMediaWrapper().removeFlags(MediaWrapper.MEDIA_FORCE_AUDIO);
                     switchToVideo();
@@ -752,7 +754,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         if (mMediaList.getMedia(mCurrentIndex).hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO) || !canSwitchToVideo())
             return false;
         if (isVideoPlaying()) {//Player is already running, just send it an intent
-            mMediaPlayer.setVideoTrackEnabled(true);
+            setVideoTrackEnabled(true);
             LocalBroadcastManager.getInstance(this).sendBroadcast(
                     VideoPlayerActivity.getIntent(VideoPlayerActivity.PLAY_FROM_SERVICE,
                             getCurrentMediaWrapper(), false, mCurrentIndex));
@@ -930,7 +932,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
      */
     private void hideNotification(boolean stopPlayback) {
         stopForeground(true);
-        NotificationManagerCompat.from(this).cancelAll();
+        NotificationManagerCompat.from(this).cancel(3);
         if(stopPlayback)
             stopSelf();
     }
@@ -958,12 +960,13 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     }
 
     @MainThread
-    public void stop() {
+    public void stopPlayback() {
         if (mMediaSession != null) {
             mMediaSession.setActive(false);
             mMediaSession.release();
             mMediaSession = null;
         }
+        removePopup();
         if (mMediaPlayer == null)
             return;
         savePosition();
@@ -984,7 +987,11 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         executeUpdate();
         executeUpdateProgress();
         changeAudioFocus(false);
+    }
 
+    @MainThread
+    public void stop() {
+        stopPlayback();
         stopSelf();
     }
 
@@ -1684,7 +1691,8 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         final Media media = new Media(VLCInstance.get(), mw.getUri());
         VLCOptions.setMediaOptions(media, this, flags | mw.getFlags());
         media.setEventListener(mMediaListener);
-        mMediaPlayer.setMedia(media);
+        if (mMediaPlayer.getMedia() == null || !mw.getUri().equals(mMediaPlayer.getMedia().getUri()))
+            mMediaPlayer.setMedia(media);
         media.release();
         if (mw .getType() != MediaWrapper.TYPE_VIDEO || mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO) || isVideoPlaying()) {
             mMediaPlayer.setEqualizer(VLCOptions.getEqualizer(this));
@@ -1728,18 +1736,50 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
      */
     @MainThread
     public void showWithoutParse(int index) {
-        String URI = mMediaList.getMRL(index);
-        Log.v(TAG, "Showing index " + index + " with playing URI " + URI);
-        // Show an URI without interrupting/losing the current stream
+        setVideoTrackEnabled(false);
+        MediaWrapper media = mMediaList.getMedia(index);
 
-        if(URI == null || !mMediaPlayer.isPlaying())
+        if(media == null || !mMediaPlayer.isPlaying())
             return;
+        // Show an URI without interrupting/losing the current stream
+        Log.v(TAG, "Showing index " + index + " with playing URI " + media.getUri());
         mCurrentIndex = index;
 
         notifyTrackChanged();
         showNotification();
     }
 
+    @MainThread
+    public void switchToPopup(int index) {
+        showWithoutParse(index);
+        showPopup();
+    }
+
+    @MainThread
+    public void removePopup() {
+        if (mPopupManager != null) {
+            mPopupManager.removePopup();
+        }
+        mPopupManager = null;
+    }
+
+    @MainThread
+    public void showPopup() {
+        if (mPopupManager == null)
+            mPopupManager = new PopupManager(this);
+        mPopupManager.showPopup();
+    }
+
+    public void setVideoTrackEnabled(boolean enabled) {
+        if (!hasMedia() || !isPlaying())
+            return;
+        if (enabled)
+            getCurrentMedia().addFlags(MediaWrapper.MEDIA_VIDEO);
+        else
+            getCurrentMedia().removeFlags(MediaWrapper.MEDIA_VIDEO);
+        mMediaPlayer.setVideoTrackEnabled(enabled);
+    }
+
     /**
      * Append to the current existing playlist
      */
