@@ -56,6 +56,7 @@ import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.interfaces.IPlaybackSettingsController;
 import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.util.AndroidDevices;
+import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.Strings;
 import org.videolan.vlc.view.AutoFitRecyclerView;
 
@@ -84,6 +85,7 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
     private static final int ID_PLAYBACK_SPEED = 6 ;
     private static final int ID_EQUALIZER = 7 ;
     private static final int ID_SAVE_PLAYLIST = 8 ;
+    private static final int ID_POPUP_VIDEO = 9 ;
 
     private Activity mActivity;
     private int mTheme;
@@ -399,6 +401,12 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
             case ID_PLAY_AS_AUDIO:
                 ((VideoPlayerActivity)getActivity()).switchToAudioMode(true);
                 break;
+            case ID_POPUP_VIDEO:
+                if (Permissions.canDrawOverlays(mActivity))
+                    ((VideoPlayerActivity)getActivity()).switchToPopupMode();
+                else
+                    Permissions.checkDrawOverlaysPermission(mActivity);
+                break;
             case ID_EQUALIZER:
                 Intent i = new Intent(getActivity(), SecondaryActivity.class);
                 i.putExtra("fragment", SecondaryActivity.EQUALIZER);
@@ -465,18 +473,22 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
 
     @Override
     public void onConnected(PlaybackService service) {
+        mAdapter.clear();
         mService = service;
         int large_items = 0;
+        boolean tvUi = VLCApplication.showTvUi();
 
         mAdapter.addOption(new Option(ID_SLEEP, R.attr.ic_sleep_normal_style));
         mAdapter.addOption(new Option(ID_PLAYBACK_SPEED, R.attr.ic_speed_normal_style));
         mAdapter.addOption(new Option(ID_JUMP_TO, R.attr.ic_jumpto_normal_style));
 
         if (mMode == MODE_VIDEO) {
-            if (!VLCApplication.showTvUi())
+            if (!tvUi)
                 mAdapter.addOption(new Option(ID_PLAY_AS_AUDIO, R.attr.ic_playasaudio_on));
             mAdapter.addOption(new Option(ID_SPU_DELAY, R.attr.ic_subtitledelay));
             mAdapter.addOption(new Option(ID_AUDIO_DELAY, R.attr.ic_audiodelay));
+            if (!tvUi)
+                mAdapter.addOption(new Option(ID_POPUP_VIDEO, R.attr.ic_popup_dim));
 
             final MediaPlayer.Chapter[] chapters = mService.getChapters(-1);
             final int chaptersCount = chapters != null ? chapters.length : 0;
@@ -577,6 +589,10 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
             return mList.size();
         }
 
+        public void clear() {
+            mList.clear();
+        }
+
         @Override
         public int getItemViewType(int position) {
             return mList.get(position).id;
